================================================================================
Test Runners
================================================================================

:abstract:

    This is a summary of the test runners included with pandokia.

.. toctree::

    runner_shell_runner.rst
    runner_maker.rst
    runner_run.rst
    runner_fctx.rst
    runner_shunit2.rst
    runner_regtest.rst
    runner_minipyt.rst
    runner_nose.rst
    runner_pytest.rst
    runner_unit2.rst
